==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/HPageBreaksCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class HPageBreaksCollection (  XlsHPageBreaksCollection) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->HPageBreak:
        """

        """
        
        GetDllLibXls().HPageBreaksCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().HPageBreaksCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibXls().HPageBreaksCollection_get_Item(self.Ptr, index)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret


    @dispatch

    def get_Item(self ,location:CellRange)->HPageBreak:
        """
    <summary>
        Gets page break object item.
    </summary>
        """
        intPtrlocation:c_void_p = location.Ptr

        GetDllLibXls().HPageBreaksCollection_get_ItemL.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_get_ItemL.restype=c_void_p
        intPtr = GetDllLibXls().HPageBreaksCollection_get_ItemL(self.Ptr, intPtrlocation)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret



    def Add(self ,range:'CellRange')->'HPageBreak':
        """
    <summary>
        Adds a horizontal page break. 
    </summary>
    <param name="location">range which new page break inserted.</param>
    <returns>HPageBreak added.</returns>
        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_Add.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_Add.restype=c_void_p
        intPtr = GetDllLibXls().HPageBreaksCollection_Add(self.Ptr, intPtrrange)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret



    def Remove(self ,range:'CellRange'):
        """

        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_Remove.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_Remove(self.Ptr, intPtrrange)

    @dispatch

    def GetPageBreak(self ,rowIndex:int)->HPageBreak:
        """
    <summary>
        Returns page break at the specified row.
    </summary>
    <param name="rowIndex">Row index.</param>
    <returns>Page break object.</returns>
        """
        
        GetDllLibXls().HPageBreaksCollection_GetPageBreak.argtypes=[c_void_p ,c_int]
        GetDllLibXls().HPageBreaksCollection_GetPageBreak.restype=c_void_p
        intPtr = GetDllLibXls().HPageBreaksCollection_GetPageBreak(self.Ptr, rowIndex)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret


    @dispatch

    def GetPageBreak(self ,range:CellRange)->HPageBreak:
        """
    <summary>
        Returns page break at the specified range.
    </summary>
    <param name="range">Range object.</param>
    <returns>Page break object.</returns>
        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_GetPageBreakR.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_GetPageBreakR.restype=c_void_p
        intPtr = GetDllLibXls().HPageBreaksCollection_GetPageBreakR(self.Ptr, intPtrrange)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/HPageBreaksCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class HPageBreaksCollection (  XlsHPageBreaksCollection) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->HPageBreak:
        """

        """
        
        GetDllLibXls().HPageBreaksCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().HPageBreaksCollection_get_Item.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().HPageBreaksCollection_get_Item, self.Ptr, index)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret


    @dispatch

    def get_Item(self ,location:CellRange)->HPageBreak:
        """
    <summary>
        Gets page break object item.
    </summary>
        """
        intPtrlocation:c_void_p = location.Ptr

        GetDllLibXls().HPageBreaksCollection_get_ItemL.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_get_ItemL.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().HPageBreaksCollection_get_ItemL, self.Ptr, intPtrlocation)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret



    def Add(self ,range:'CellRange')->'HPageBreak':
        """
    <summary>
        Adds a horizontal page break. 
    </summary>
    <param name="location">range which new page break inserted.</param>
    <returns>HPageBreak added.</returns>
        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_Add.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_Add.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().HPageBreaksCollection_Add, self.Ptr, intPtrrange)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret



    def Remove(self ,range:'CellRange'):
        """

        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_Remove.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().HPageBreaksCollection_Remove, self.Ptr, intPtrrange)

    @dispatch

    def GetPageBreak(self ,rowIndex:int)->HPageBreak:
        """
    <summary>
        Returns page break at the specified row.
    </summary>
    <param name="rowIndex">Row index.</param>
    <returns>Page break object.</returns>
        """
        
        GetDllLibXls().HPageBreaksCollection_GetPageBreak.argtypes=[c_void_p ,c_int]
        GetDllLibXls().HPageBreaksCollection_GetPageBreak.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().HPageBreaksCollection_GetPageBreak, self.Ptr, rowIndex)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret


    @dispatch

    def GetPageBreak(self ,range:CellRange)->HPageBreak:
        """
    <summary>
        Returns page break at the specified range.
    </summary>
    <param name="range">Range object.</param>
    <returns>Page break object.</returns>
        """
        intPtrrange:c_void_p = range.Ptr

        GetDllLibXls().HPageBreaksCollection_GetPageBreakR.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().HPageBreaksCollection_GetPageBreakR.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().HPageBreaksCollection_GetPageBreakR, self.Ptr, intPtrrange)
        ret = None if intPtr==None else HPageBreak(intPtr)
        return ret
